@@ -16,7 +16,7 @@ MIT
 """
 import json
 import requests
-from IPython.display import display, HTML, image
+from IPython.display import display, HTML, Image
 from IPython.core.display import Video
 
 session = requests.Session()
